{% extends "base.html" %}

{% block content %}
  <!-- Main jumbotron for a primary marketing message or call to action -->
  <div class="jumbotron">
    <h1>dj-rest-auth demo</h1>
    <p>Welcome in dj-rest-auth demo project!</p>
  </div>
{% endblock %}
