<!-- Signup form -->
<form class="form-horizontal ajax-post" role="form" action="{% url 'rest_password_reset_confirm' %}">{% csrf_token %}
  <div class="form-group">
    <label for="uid" class="col-sm-2 control-label">Uid</label>
    <div class="col-sm-10">
      <input name="uid" type="text" class="form-control" id="uid" placeholder="Uid">
      <p class="help-block">Uid value sent in email</p>
    </div>
  </div>

  <div class="form-group">
    <label for="token" class="col-sm-2 control-label">Token</label>
    <div class="col-sm-10">
      <input name="token" type="text" class="form-control" id="token" placeholder="Token">
      <p class="help-block">Token value sent in email</p>
    </div>
  </div>

  <div class="form-group">
    <label for="new_password1" class="col-sm-2 control-label">Password</label>
    <div class="col-sm-10">
      <input name="new_password1" type="password" class="form-control" id="new_password1" placeholder="Password">
    </div>
  </div>

  <div class="form-group">
    <label for="new_password2" class="col-sm-2 control-label">Repeat password</label>
    <div class="col-sm-10">
      <input name="new_password2" type="password" class="form-control" id="new_password2" placeholder="Repeat password">
    </div>
  </div>

  <div class="form-group">
    <div class="col-sm-offset-2 col-sm-10">
      <button type="submit" class="btn btn-default">Set new password</button>
    </div>
  </div>

  <div class="form-group api-response"></div>
</form>
