<!-- Signup form -->
<form class="form-horizontal" id="signup" role="form" action="{% url 'rest_user_details' %}">{% csrf_token %}

  <div class="form-group">
    <label for="email" class="col-sm-2 control-label">Email</label>
    <div class="col-sm-10">
      <input name="email" type="text" class="form-control" id="email" placeholder="Email">
    </div>
  </div>

  <div class="form-group">
    <label for="username" class="col-sm-2 control-label">Username</label>
    <div class="col-sm-10">
      <input name="username" type="text" class="form-control" id="username" placeholder="Username">
    </div>
  </div>

  <div class="form-group">
    <label for="first_name" class="col-sm-2 control-label">First name</label>
    <div class="col-sm-10">
      <input name="first_name" type="text" class="form-control" id="first_name" placeholder="First name">
    </div>
  </div>

  <div class="form-group">
    <label for="last_name" class="col-sm-2 control-label">Last name</label>
    <div class="col-sm-10">
      <input name="last_name" type="text" class="form-control" id="last_name" placeholder="Last name">
    </div>
  </div>

  <div class="form-group">
    <div class="col-sm-offset-2 col-sm-10">
      <button type="submit" class="btn btn-default">Save</button>
    </div>
  </div>

  <div class="form-group api-response"></div>
</form>
